/* Client aboutfile */
gchar *text="GTK Crossfire Client\n\
Authors of the client: \n\
Mark Wedel (mwedel@sonic.net) - general client source and Xlib client\n\
David Sundqvist (azzie@netpolicy.com) - GTK+ port\n\
Raphael Quinet (Raphael.Quinet@eed.ericsson.se) - Configure scripts \n\
and graphics\n\
Eric Anderson did a lot of initial work on the client.\n\
\n\
This program is free software; you can redistribute it and/or modify\n\
it under the terms of the GNU General Public License as published by\n\
the Free Software Foundation; either version 2 of the License, or\n\
(at your option) any later version.\n\
\n\
This program is distributed in the hope that it will be useful,\n\
but WITHOUT ANY WARRANTY; without even the implied warranty of\n\
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n\
GNU General Public License for more details.\n\
\n\
You should have received a copy of the GNU General Public License\n\
along with this program; if not, write to the Free Software\n\
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 \n\
USA";

